NAME

DateTime::TimeZone::America::Indiana::Marengo - Time zone data for America/Indiana/Marengo

SYNOPSIS

my $timezone = DateTime::TimeZone->new( name => 'America/Indiana/Marengo' );

DESCRIPTION

This module is an internal timezone definition data file used by DateTime::TimeZone. You do not need to use this module directly.